@@ -15,9 +15,11 @@ class Snippet(object):
         return self.args.get(name, {})
 
     def get_run_section(self, section_name='run'):
-        return copy.deepcopy(self.parsed_yaml.get(section_name or 'run', []))
+        return copy.deepcopy(self.parsed_yaml.get(section_name, None))
 
     def get_dependencies_section(self, section_name='dependencies'):
+        if not section_name in self.parsed_yaml:
+            return None
         # we also want to include the basic "dependencies" section
         deps = copy.deepcopy(self.parsed_yaml.get('dependencies', []))
         if section_name != 'dependencies':
