@@ -14,7 +14,7 @@ class CreatorAssistant(ExecutableAssistant):
 
     name = 'main'
     verbose_name = 'Main'
-    description = 'Developer assistant will help you with creating projects in many different languages.\
+    description = 'Developer Assistant will help you with creating projects in many different languages.\
                    See subassistants for list of currently available assistants.'
 
 class ModifierAssistant(ExecutableAssistant):
@@ -24,5 +24,16 @@ class ModifierAssistant(ExecutableAssistant):
 
     name = 'main'
     verbose_name = 'Main'
-    description = 'Developer assistant will help you work with existing projects.\
+    description = 'Developer Assistant - Modify will help you work with existing projects.\
+                   See subassistants for list of currently available assistants.'
+
+class PreparerAssistant(ExecutableAssistant):
+    def get_subassistants(self):
+        sa = yaml_assistant_loader.YamlAssistantLoader.get_top_level_assistants(roles=['preparer'])
+        return sa
+
+    name = 'main'
+    verbose_name = 'Main'
+    description = 'Developer Assistant - Prepare will help you setup your environment for \
+                   working with upstream projects.\
                    See subassistants for list of currently available assistants.'
