@@ -1,8 +1,9 @@
 import argparse
 
 from devassistant.cli import devassistant_argparse
-
+from devassistant import command_helpers
 from devassistant import settings
+from devassistant import argument
 
 class ArgparseGenerator(object):
     subassistants_string = 'subassistants'
@@ -17,6 +18,12 @@ class ArgparseGenerator(object):
         for arg in cur_as.args:
             arg.add_argument_to(parser)
 
+        # add the argument for UI choice
+        command_helpers.DialogHelper.get_argparse_argument().add_argument_to(parser)
+        help='Devassistant will only install packages'
+        parser.add_argument(settings.DEPS_ONLY_FLAG, required=False, action='store_true', help=help)
+
+
         if cur_subas:
             # then add the subassistants as arguments
             subparsers = parser.add_subparsers(dest=settings.SUBASSISTANT_N_STRING.format('0'),
