@@ -18,3 +18,9 @@ class ClException(RunException):
 
 class AssistantNotFoundException(BaseException):
     pass
+
+class SnippetNotFoundException(BaseException):
+    pass
+
+class YamlSyntaxError(BaseException):
+    pass
