@@ -1,3 +1,4 @@
+import os
 GITHUB_SSH_CONFIG = '''
 # devassistant config for user {login}
 Host github.com-{login}
@@ -9,3 +10,8 @@ LOG_FORMATS_MAP = {'log_cmd': u'{levelname}: {msg}', 'cmd_call': u'[devassistant
 LOG_LEVELS_MAP = {'d': 'DEBUG', 'i': 'INFO', 'w': 'WARNING', 'e': 'ERROR', 'c': 'CRITICAL'}
 SUBASSISTANT_PREFIX = 'subassistant'
 SUBASSISTANT_N_STRING = 'subassistant_{0}'
+UI_FLAG = '--ui'
+DEPS_ONLY_FLAG = '--deps-only'
+YAML_DIRECTORIES = [os.path.join(os.path.dirname(__file__), 'yaml'),
+                    '/usr/local/share/devassistant',
+                    os.path.expanduser('~/.devassistant')]
